@@ -172,7 +172,7 @@ Vue.component('edit-field', {
     },
     data: function () {
         var schemaType, fieldType = 'text', inputMode = 'text', children = [],
-            pattern = this.schema.pattern;
+            pattern = this.schema.pattern, value = this.value;
 
         if ( Array.isArray( this.schema.type ) ) {
             schemaType = this.schema.type[0];
@@ -214,6 +214,9 @@ Vue.component('edit-field', {
             }
             else if ( this.schema.format == 'date-time' ) {
                 fieldType = 'datetime-local';
+                // Verify the value lacks seconds, since datetime-local
+                // fields do not support seconds...
+                value = value.replace( /^(\d{4}-\d{2}-\d{2}[ T]\d{2}:\d{2}).*/, '$1' );
             }
             else if ( this.schema.format == 'markdown' ) {
                 fieldType = 'markdown';
@@ -234,7 +237,7 @@ Vue.component('edit-field', {
         }
         else if (schemaType == 'array') {
             fieldType = 'array';
-            children = (this.value || []).map(function (v, ix) {
+            children = (value || []).map(function (v, ix) {
               return ({
                 name: this.name + "-"+ix,
                 example: this.schema.items.example,
@@ -253,7 +256,7 @@ Vue.component('edit-field', {
             readonly: this.schema.readOnly,
             writeonly: this.schema.writeOnly,
             inputMode: inputMode,
-            _value: this.value,
+            _value: value,
             showHtml: false,
             children: children
         };
