@@ -24,7 +24,8 @@ CREATE TABLE blog (
     slug VARCHAR(255),
     markdown VARCHAR(255) NOT NULL,
     html VARCHAR(255),
-    is_published BOOLEAN NOT NULL DEFAULT FALSE
+    is_published BOOLEAN NOT NULL DEFAULT FALSE,
+    published_date DATETIME DEFAULT CURRENT_TIMESTAMP
 );
 CREATE TABLE mojo_migrations (
     name VARCHAR(255) UNIQUE NOT NULL,
